@@ -29,25 +29,6 @@ class hook_cache:
         return self.all_hooks
 
 
-class group_cache:
-    _user_groups = {}
-
-    def set_user(self, user: User):
-        self._user_groups[user.id] = set(
-            user.groups.all().values_list('id', flat=True))
-
-    def get_user(self, user: User):
-        return self._user_groups.get(user.id, set())
-
-    def clear_user(self, user: User):
-        try:
-            del self._user_groups[user.id]
-            return True
-        except KeyError:
-            return False
-
-
-signal_cache = group_cache()
 filters = hook_cache()
 
 
@@ -88,18 +69,20 @@ for _filter in filters.get_hooks():
 
 
 @receiver(m2m_changed, sender=User.groups.through)
-def m2m_changed_user_groups(sender, instance: User, action, *args, **kwargs):
+def m2m_changed_user_groups(sender, instance: User, action, pk_set, *args, **kwargs):
     logger.debug("Received m2m_changed from %s groups with action %s" %
                  (instance, action))
 
     def trigger_group_checks():
         logger.debug("Checking user is valid for SmartGroups! %s" % instance)
         # find the groups!
-        users_groups = instance.groups.filter(smartgroup__isnull=False)
-        old_groups = signal_cache.get_user(instance)
+        users_groups = instance.groups.filter(
+            pk__in=pk_set, smartgroup__isnull=False)
         groups_to_remove = []
         for g in users_groups:
-            if g.id not in old_groups:
+            logger.debug(
+                F"Checking {instance} can access ({g.id}) PK_SET:({pk_set})")
+            if g.id in pk_set:
                 sg_check = g.smartgroup.check_user(instance)
                 if not sg_check:
                     groups_to_remove.append(g)
@@ -107,12 +90,8 @@ def m2m_changed_user_groups(sender, instance: User, action, *args, **kwargs):
                         "Removing {} from {}, due to invalid join".format(instance, g))
         if len(groups_to_remove) > 0:
             instance.groups.remove(*groups_to_remove)
-        signal_cache.clear_user(instance)
 
     if instance.pk and (action == "post_add"):
         logger.debug(
             "Waiting for commit to Checking user is valid for SmartGroups! %s" % instance)
         transaction.on_commit(trigger_group_checks)
-
-    if instance.pk and (action == "pre_add"):
-        signal_cache.set_user(instance)
